import sys
import argparse
import qtpy

if not qtpy.PYQT5 and not qtpy.PYSIDE2:
    if sys.platform == 'linux':
        sys.exit("Error: a compatible Qt library couldn't be imported.\n"
                 "Please install python3-pyqt5 (or just python-pyqt5) from your package manager.")
    else:  # this technically shouldn't ever happen
        sys.exit("Error: a compatible Qt library couldn't be imported.\n"
                 "Please install it by running `pip install pyqt5")


def main():
    import signal
    import serial
    from .config import ROOT_LOG
    from .main_window import MainWindow
    from .serial import SerialConnection
    from .resources import qCleanupResources
    from qtpy.QtGui import QIcon
    from qtpy.QtWidgets import QApplication

    if sys.platform == 'win32':
        import ctypes
        appid = 'busimus.cutelog'
        ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(appid)

    parser = argparse.ArgumentParser(description='Open a serial port and neatly display log messages')
    parser.add_argument('port', metavar='Serial port', type=str, nargs=1,
                        help='Serial port to open')
    parser.add_argument('baud', metavar='Baud Rate', type=int, nargs=1,
                        help='baud rate')


    args = parser.parse_args()
    try:
        ser = SerialConnection(None, args.port[0], args.baud[0])
    except serial.serialutil.SerialException as err:
        sys.exit("Error opening serial port: {}".format(str(err)))
     
    app = QApplication(sys.argv)
    app.setWindowIcon(QIcon(':/cutelog.png'))
    mw = MainWindow(ROOT_LOG, app)
    signal.signal(signal.SIGINT, mw.signal_handler)

    sys.exit(app.exec_())
    qCleanupResources()


if __name__ == '__main__':
    main()
